@@ -36,21 +36,17 @@ bitvalue_c::bitvalue_c(const bitvalue_c &src) {
 bitvalue_c::bitvalue_c(std::string s,
                        unsigned int allowed_bitlength) {
   if ((allowed_bitlength != 0) && ((allowed_bitlength % 8) != 0))
-    throw error_c("wrong usage: invalid allowed_bitlength");
+    throw mtx::invalid_parameter_x();
 
-  unsigned int len        = s.size();
-  bool previous_was_space = true;
-  s                       = downcase(s);
+  unsigned int len = s.size();
+  ba::to_lower(s);
   std::string s2;
 
   unsigned int i;
   for (i = 0; i < len; i++) {
     // Space or tab?
-    if (isblanktab(s[i])) {
-      previous_was_space = true;
+    if (isblanktab(s[i]))
       continue;
-    }
-    previous_was_space = false;
 
     // Skip hyphens and curly braces. Makes copy & paste a bit easier.
     if ((s[i] == '-') || (s[i] == '{') || (s[i] == '}'))
@@ -64,11 +60,11 @@ bitvalue_c::bitvalue_c(std::string s,
 
     // Invalid character?
     if (!ishexdigit(s[i]))
-      throw error_c(boost::format(Y("Not a hex digit at position %1%")) % i);
+      throw mtx::bitvalue_parser_x(boost::format(Y("Not a hex digit at position %1%")) % i);
 
     // Input too long?
     if ((allowed_bitlength > 0) && ((s2.length() * 4) >= allowed_bitlength))
-      throw error_c(boost::format(Y("Input too long: %1% > %2%")) % (s2.length() * 4) % allowed_bitlength);
+      throw mtx::bitvalue_parser_x(boost::format(Y("Input too long: %1% > %2%")) % (s2.length() * 4) % allowed_bitlength);
 
     // Store the value.
     s2 += s[i];
@@ -79,7 +75,7 @@ bitvalue_c::bitvalue_c(std::string s,
   if (((len % 2) != 0)
       ||
       ((allowed_bitlength != 0) && ((len * 4) < allowed_bitlength)))
-    throw error_c(Y("Missing one hex digit"));
+    throw mtx::bitvalue_parser_x(Y("Missing one hex digit"));
 
   m_value = memory_c::alloc(len / 2);
 
@@ -112,7 +108,7 @@ bitvalue_c::operator ==(const bitvalue_c &cmp)
 unsigned char
 bitvalue_c::operator [](size_t index)
   const {
-  assert((0 <= index) && (m_value->get_size() > index));
+  assert(m_value->get_size() > index);
   return m_value->get_buffer()[index];
 }
 
