@@ -19,8 +19,8 @@
 #endif
 
 #include "common/command_line.h"
-#include "common/mm_io.h"
-#include "common/mm_write_cache_io.h"
+#include "common/hacks.h"
+#include "common/mm_write_buffer_io.h"
 #include "common/strings/editing.h"
 #include "common/translation.h"
 #include "common/version.h"
@@ -177,6 +177,14 @@ handle_common_cli_args(std::vector<std::string> &args,
       debug_options_found = true;
 
       args.erase(args.begin() + i, args.begin() + i + 2);
+
+    } else if (args[i] == "--engage") {
+      if ((i + 1) == args.size())
+        mxerror(Y("'--engage' lacks its argument.\n"));
+
+      engage_hacks(args[i + 1]);
+      args.erase(args.begin() + i, args.begin() + i + 2);
+
     } else
       ++i;
   }
@@ -203,7 +211,7 @@ handle_common_cli_args(std::vector<std::string> &args,
         mxerror(boost::format(Y("'%1%' is missing the file name.\n")) % args[i]);
       try {
         if (!stdio_redirected()) {
-          mm_io_cptr file = mm_write_cache_io_c::open(args[i + 1], 128 * 1024);
+          mm_io_cptr file = mm_write_buffer_io_c::open(args[i + 1], 128 * 1024);
           file->write_bom(g_stdio_charset);
           redirect_stdio(file);
         }
