@@ -21,6 +21,8 @@
 
 #include <matroska/KaxTracks.h>
 
+#include "common/smart_pointers.h"
+
 using namespace libebml;
 using namespace libmatroska;
 
@@ -208,4 +210,7 @@ provide_default_for_child(EbmlMaster *master,
   provide_default_for_child<A>(*master, default_value);
 }
 
+typedef counted_ptr<EbmlElement> ebml_element_cptr;
+typedef counted_ptr<EbmlMaster> ebml_master_cptr;
+
 #endif // __MTX_COMMON_EBML_H
