@@ -11,10 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <stdio.h>
-#include <string.h>
-
 #include "common/common_pch.h"
+
 #include "common/iso639.h"
 #include "common/strings/editing.h"
 #include "common/strings/utf8.h"
@@ -88,7 +86,6 @@ const iso639_language_t iso639_languages[] = {
   { "Buriat",                                                                           "bua", NULL, NULL  },
   { "Burmese",                                                                          "bur", "my", "mya" },
   { "Caddo",                                                                            "cad", NULL, NULL  },
-  { "Castilian",                                                                        "spa", "es", NULL  },
   { "Catalan; Valencian",                                                               "cat", "ca", NULL  },
   { "Caucasian languages",                                                              "cau", NULL, NULL  },
   { "Cebuano",                                                                          "ceb", NULL, NULL  },
@@ -425,7 +422,7 @@ const iso639_language_t iso639_languages[] = {
   { "South American Indian (Other)",                                                    "sai", NULL, NULL  },
   { "Southern Altai",                                                                   "alt", NULL, NULL  },
   { "Southern Sami",                                                                    "sma", NULL, NULL  },
-  { "Spanish",                                                                          "spa", "es", NULL  },
+  { "Spanish; Castillan",                                                               "spa", "es", NULL  },
   { "Sranan Tongo",                                                                     "srn", NULL, NULL  },
   { "Sukuma",                                                                           "suk", NULL, NULL  },
   { "Sumerian",                                                                         "sux", NULL, NULL  },
@@ -561,38 +558,39 @@ map_iso639_2_to_iso639_1(const char *iso639_2_code) {
 
 bool
 is_popular_language(const char *lang) {
-  return
-    !strcmp(lang, "Chinese") ||
-    !strcmp(lang, "Dutch") ||
-    !strcmp(lang, "English") ||
-    !strcmp(lang, "Finnish") ||
-    !strcmp(lang, "French") ||
-    !strcmp(lang, "German") ||
-    !strcmp(lang, "Italian") ||
-    !strcmp(lang, "Japanese") ||
-    !strcmp(lang, "Norwegian") ||
-    !strcmp(lang, "Portuguese") ||
-    !strcmp(lang, "Russian") ||
-    !strcmp(lang, "Spanish") ||
-    !strcmp(lang, "Swedish");
+  return !strcmp(lang, "Chinese")
+      || !strcmp(lang, "Dutch")
+      || !strcmp(lang, "English")
+      || !strcmp(lang, "Finnish")
+      || !strcmp(lang, "French")
+      || !strcmp(lang, "German")
+      || !strcmp(lang, "Italian")
+      || !strcmp(lang, "Japanese")
+      || !strcmp(lang, "Norwegian")
+      || !strcmp(lang, "Portuguese")
+      || !strcmp(lang, "Russian")
+      || !strcmp(lang, "Spanish")
+      || !strcmp(lang, "Spanish; Castillan")
+      || !strcmp(lang, "Swedish")
+    ;
 }
 
 bool
 is_popular_language_code(const char *code) {
-  return
-    !strcmp(code, "chi") || // Chinese
-    !strcmp(code, "dut") || // Dutch
-    !strcmp(code, "eng") || // English
-    !strcmp(code, "fin") || // Finnish
-    !strcmp(code, "fre") || // French
-    !strcmp(code, "ger") || // German
-    !strcmp(code, "ita") || // Italian
-    !strcmp(code, "jpn") || // Japanese
-    !strcmp(code, "nor") || // Norwegian
-    !strcmp(code, "por") || // Portuguese
-    !strcmp(code, "rus") || // Russian
-    !strcmp(code, "spa") || // Spanish
-    !strcmp(code, "swe");   // Swedish
+  return !strcmp(code, "chi") // Chinese
+      || !strcmp(code, "dut") // Dutch
+      || !strcmp(code, "eng") // English
+      || !strcmp(code, "fin") // Finnish
+      || !strcmp(code, "fre") // French
+      || !strcmp(code, "ger") // German
+      || !strcmp(code, "ita") // Italian
+      || !strcmp(code, "jpn") // Japanese
+      || !strcmp(code, "nor") // Norwegian
+      || !strcmp(code, "por") // Portuguese
+      || !strcmp(code, "rus") // Russian
+      || !strcmp(code, "spa") // Spanish
+      || !strcmp(code, "swe") // Swedish
+    ;
 }
 
 /** \brief Map a string to a ISO 639-2 language code
