@@ -17,12 +17,17 @@
 
 #include "common/ivf.h"
 
-ivf_file_header_t::ivf_file_header_t()
+ivf::file_header_t::file_header_t()
 {
   memset(this, 0, sizeof(*this));
 }
 
-ivf_frame_header_t::ivf_frame_header_t()
+ivf::frame_header_t::frame_header_t()
 {
   memset(this, 0, sizeof(*this));
 }
+
+bool
+ivf::is_keyframe(const memory_cptr &buffer) {
+  return buffer.is_set() && (0 < buffer->get_size()) && ((buffer->get_buffer()[0] & 0x01) == 0);
+}
