@@ -31,14 +31,14 @@ xtr_cpic_c::xtr_cpic_c(const std::string &codec_id,
 
 void
 xtr_cpic_c::handle_frame(memory_cptr &frame,
-                         KaxBlockAdditions *additions,
-                         int64_t timecode,
-                         int64_t duration,
-                         int64_t bref,
-                         int64_t fref,
-                         bool keyframe,
-                         bool discardable,
-                         bool references_valid) {
+                         KaxBlockAdditions *,
+                         int64_t,
+                         int64_t,
+                         int64_t,
+                         int64_t,
+                         bool,
+                         bool,
+                         bool) {
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
   binary *mybuffer = frame->get_buffer();
@@ -65,16 +65,15 @@ xtr_cpic_c::handle_frame(memory_cptr &frame,
       frame_file_name += ".png";
   }
 
-  m_out = new mm_file_io_c(frame_file_name, MODE_CREATE);
+  m_out = mm_file_io_c::open(frame_file_name, MODE_CREATE);
   m_out->write(&mybuffer[header_size], data_size - header_size);
-  delete m_out;
-  m_out = NULL;
+  m_out.clear();
 
   ++m_frame_counter;
 }
 
 void
-xtr_cpic_c::create_file(xtr_base_c *master,
+xtr_cpic_c::create_file(xtr_base_c *,
                         KaxTrackEntry &track) {
   init_content_decoder(track);
 }
