@@ -47,6 +47,7 @@ class ogm_reader_c;
 class ogm_demuxer_c {
 public:
   ogm_reader_c *reader;
+  track_info_c &m_ti;
 
   ogg_stream_state os;
   int ptzr;
@@ -77,7 +78,7 @@ public:
 
   virtual void initialize() {
   };
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti) {
+  virtual generic_packetizer_c *create_packetizer() {
     return NULL;
   };
   virtual void process_page(int64_t granulepos);
@@ -94,24 +95,25 @@ typedef counted_ptr<ogm_demuxer_c> ogm_demuxer_cptr;
 class ogm_reader_c: public generic_reader_c {
 private:
   ogg_sync_state oy;
-  mm_io_c *io;
   std::vector<ogm_demuxer_cptr> sdemuxers;
   int bos_pages_read;
-  int64_t file_size;
 
 public:
-  ogm_reader_c(track_info_c &_ti) throw (error_c);
+  ogm_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~ogm_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("Ogg/OGM") : "Ogg/OGM";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizers();
   virtual void create_packetizer(int64_t tid);
   virtual void add_available_track_ids();
 
-  virtual int get_progress();
-
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static int probe_file(mm_io_c *in, uint64_t size);
 
 private:
   virtual ogm_demuxer_cptr find_demuxer(int serialno);
@@ -120,7 +122,7 @@ private:
   virtual void handle_new_stream_and_packets(ogg_page *);
   virtual void process_page(ogg_page *);
   virtual int packet_available();
-  virtual int read_headers();
+  virtual int read_headers_internal();
   virtual void process_header_page(ogg_page *pg);
   virtual void process_header_packets(ogm_demuxer_cptr dmx);
   virtual void handle_stream_comments();
