@@ -24,17 +24,19 @@
 
 class pgssup_reader_c: public generic_reader_c {
 private:
-  mm_io_cptr m_in;
-  uint64_t m_bytes_processed, m_file_size;
   bool m_debug;
 
 public:
-  pgssup_reader_c(track_info_c &p_ti);
+  pgssup_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~pgssup_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("PGSSUP") : "PGSSUP";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
-  virtual int get_progress();
   virtual void create_packetizer(int64_t id);
   virtual bool is_simple_subtitle_container() {
     return true;
