@@ -23,39 +23,42 @@
 
 
 int
-ssa_reader_c::probe_file(mm_text_io_c *io,
+ssa_reader_c::probe_file(mm_text_io_c *in,
                          uint64_t) {
-  return ssa_parser_c::probe(io);
+  return ssa_parser_c::probe(in);
 }
 
-ssa_reader_c::ssa_reader_c(track_info_c &_ti)
-  throw (error_c)
-  : generic_reader_c(_ti)
+ssa_reader_c::ssa_reader_c(const track_info_c &ti,
+                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
 {
-  counted_ptr<mm_text_io_c> io;
+}
+
+void
+ssa_reader_c::read_headers() {
+  mm_text_io_cptr text_in;
 
   try {
-    io = counted_ptr<mm_text_io_c>(new mm_text_io_c(new mm_file_io_c(m_ti.m_fname)));
+    text_in = counted_ptr<mm_text_io_c>(new mm_text_io_c(m_in.get_object(), false));
   } catch (...) {
-    throw error_c(Y("ssa_reader: Could not open the source file."));
+    throw mtx::input::open_x();
   }
 
-  if (!ssa_reader_c::probe_file(io.get_object(), 0))
-    throw error_c(Y("ssa_reader: Source is not a valid SSA/ASS file."));
+  if (!ssa_reader_c::probe_file(text_in.get_object(), 0))
+    throw mtx::input::invalid_format_x();
 
   charset_converter_cptr cc_utf8 = map_has_key(m_ti.m_sub_charsets,  0) ? charset_converter_c::init(m_ti.m_sub_charsets[ 0])
                                  : map_has_key(m_ti.m_sub_charsets, -1) ? charset_converter_c::init(m_ti.m_sub_charsets[-1])
-                                 : io->get_byte_order() != BO_NONE      ? charset_converter_c::init("UTF-8")
+                                 : text_in->get_byte_order() != BO_NONE ? charset_converter_c::init("UTF-8")
                                  :                                        g_cc_local_utf8;
 
   m_ti.m_id = 0;
-  m_subs    = ssa_parser_cptr(new ssa_parser_c(this, io.get_object(), m_ti.m_fname, 0));
+  m_subs    = ssa_parser_cptr(new ssa_parser_c(this, text_in.get_object(), m_ti.m_fname, 0));
 
   m_subs->set_charset_converter(cc_utf8);
   m_subs->parse();
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the SSA/ASS subtitle reader.\n"));
+  show_demuxer_info();
 }
 
 ssa_reader_c::~ssa_reader_c() {
@@ -68,7 +71,7 @@ ssa_reader_c::create_packetizer(int64_t) {
 
   std::string global = m_subs->get_global();
   add_packetizer(new textsubs_packetizer_c(this, m_ti, m_subs->is_ass() ?  MKV_S_TEXTASS : MKV_S_TEXTSSA, global.c_str(), global.length(), false, false));
-  mxinfo_tid(m_ti.m_fname, 0, Y("Using the text subtitle output module.\n"));
+  show_packetizer_info(0, PTZR0);
 }
 
 file_status_e
@@ -89,7 +92,7 @@ ssa_reader_c::get_progress() {
 
 void
 ssa_reader_c::identify() {
-  id_result_container("SSA/ASS");
+  id_result_container();
   id_result_track(0, ID_RESULT_TRACK_SUBTITLES, "SSA/ASS");
 
   size_t i;
