@@ -141,7 +141,7 @@ set_usage() {
                   "                           Matroska file.\n");
   usage_text += Y("  --attach-file-once <file>\n"
                   "                           Creates a file attachment inside the\n"
-                  "                           firsts Matroska file written.\n");
+                  "                           first Matroska file written.\n");
   usage_text +=   "\n";
   usage_text += Y(" Options for each input file:\n");
   usage_text += Y("  -a, --audio-tracks <n,m,...>\n"
@@ -251,7 +251,9 @@ set_usage() {
                   "                           the specified file (see man page).\n");
   usage_text += Y("  -h, --help               Show this help.\n");
   usage_text += Y("  -V, --version            Show version information.\n");
+#if defined(HAVE_CURL_EASY_H)
   usage_text += std::string("  --check-for-updates      ") + Y("Check online for the latest release.") + "\n";
+#endif
   usage_text +=   "\n\n";
   usage_text += Y("Please read the man page/the HTML documentation to mkvmerge. It\n"
                   "explains several details in great length which are not obvious from\n"
