@@ -11,13 +11,20 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
+// This order is required. wx/wxprec.h includes wx's winundef.h which
+// cannot be included after windows.h has been included. But
+// mkvtoolnix' common.h includes windows.h.
+#undef __STRICT_ANSI__
+
+#include <wx/wxprec.h>
+
+#include "common/common.h"
+
 #include <errno.h>
 
 #include <algorithm>
 #include <map>
 
-#include <wx/wxprec.h>
-
 #include <wx/wx.h>
 #include <wx/dnd.h>
 #include <wx/file.h>
@@ -26,7 +33,6 @@
 #include <wx/regex.h>
 #include <wx/statline.h>
 
-#include "common/common_pch.h"
 #include "common/extern_data.h"
 #include "common/file_types.h"
 #include "common/iso639.h"
@@ -73,7 +79,7 @@ private:
 public:
   input_drop_target_c(tab_input *n_owner):
     owner(n_owner) {}
-  virtual bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString &dropped_files) {
+  virtual bool OnDropFiles(wxCoord /* x */, wxCoord /* y */, const wxArrayString &dropped_files) {
     size_t i;
 
     for (i = 0; i < dropped_files.Count(); i++)
@@ -223,11 +229,11 @@ tab_input::setup_file_type_filter() {
   std::map<wxString, bool> all_extensions_map;
   wxString filters;
 
-  foreach(file_type_t &file_type, file_types) {
+  for (auto &file_type : file_types) {
     std::vector<wxString> extensions = split(wxU(file_type.extensions), wxU(" "));
     std::vector<wxString> extensions_full;
 
-    foreach(wxString &extension, extensions) {
+    for (auto &extension : extensions) {
       all_extensions_map[extension] = true;
       extensions_full.push_back(wxString::Format(wxT("*.%s"), extension.c_str()));
 
@@ -244,7 +250,7 @@ tab_input::setup_file_type_filter() {
   }
 
   std::vector<wxString> all_extensions;
-  foreach(wxstring_bool_pair_t &extension, all_extensions_map)
+  for (auto &extension : all_extensions_map)
     all_extensions.push_back(wxString::Format(wxT("*.%s"), extension.first.c_str()));
 
   std::sort(all_extensions.begin(), all_extensions.end());
@@ -269,12 +275,12 @@ tab_input::select_file(bool append) {
 }
 
 void
-tab_input::on_add_file(wxCommandEvent &evt) {
+tab_input::on_add_file(wxCommandEvent &) {
   select_file(false);
 }
 
 void
-tab_input::on_append_file(wxCommandEvent &evt) {
+tab_input::on_append_file(wxCommandEvent &) {
   select_file(true);
 }
 
@@ -290,8 +296,8 @@ tab_input::add_file(const wxString &file_name,
   std::string arg_utf8;
 
   wxFileName file_name_obj(file_name);
-  foreach(mmg_file_cptr file_itr, files)
-    foreach(const wxFileName &other_file_name, file_itr->other_files)
+  for (auto file : files)
+    for (auto &other_file_name : file->other_files)
       if (file_name_obj == other_file_name) {
         wxMessageBox(wxString::Format(Z("The file '%s' is already processed in combination with the file '%s'. It cannot be added a second time."),
                                       file_name_obj.GetFullPath().c_str(), other_file_name.GetFullPath().c_str()),
@@ -705,7 +711,7 @@ tab_input::add_file(const wxString &file_name,
   if (!file->other_files.empty()) {
     std::vector<wxString> other_file_names;
 
-    foreach(const wxFileName &other_file_name, file->other_files)
+    for (auto &other_file_name : file->other_files)
       other_file_names.push_back(other_file_name.GetFullName());
 
     wxMessageBox(wxU(boost::wformat(Z("'%1%': Processing the following files as well: %2%\n").c_str()) % file_name.c_str() % join(L", ", other_file_names).c_str()),
@@ -714,7 +720,7 @@ tab_input::add_file(const wxString &file_name,
 }
 
 void
-tab_input::on_remove_file(wxCommandEvent &evt) {
+tab_input::on_remove_file(wxCommandEvent &) {
   mmg_track_t *t;
   std::vector<mmg_file_t>::iterator eit;
 
@@ -781,7 +787,7 @@ tab_input::on_remove_file(wxCommandEvent &evt) {
 }
 
 void
-tab_input::on_remove_all_files(wxCommandEvent &evt) {
+tab_input::on_remove_all_files(wxCommandEvent &) {
   dont_copy_values_now = true;
 
   mdlg->attachments_page->remove_all_attached_files();
@@ -810,7 +816,7 @@ tab_input::on_remove_all_files(wxCommandEvent &evt) {
 }
 
 void
-tab_input::on_move_track_up(wxCommandEvent &evt) {
+tab_input::on_move_track_up(wxCommandEvent &) {
   if (1 > selected_track)
     return;
 
@@ -842,7 +848,7 @@ tab_input::on_move_track_up(wxCommandEvent &evt) {
 }
 
 void
-tab_input::on_move_track_down(wxCommandEvent &evt) {
+tab_input::on_move_track_down(wxCommandEvent &) {
   if ((0 > selected_track) || (static_cast<size_t>(selected_track) >= tracks.size() - 1))
     return;
 
@@ -874,7 +880,7 @@ tab_input::on_move_track_down(wxCommandEvent &evt) {
 }
 
 void
-tab_input::on_file_selected(wxCommandEvent &evt) {
+tab_input::on_file_selected(wxCommandEvent &) {
   selected_file = -1;
   int new_sel   = lb_input_files->GetSelection();
   if (0 > new_sel)
@@ -887,7 +893,7 @@ tab_input::on_file_selected(wxCommandEvent &evt) {
 }
 
 void
-tab_input::on_track_selected(wxCommandEvent &evt) {
+tab_input::on_track_selected(wxCommandEvent &) {
   dont_copy_values_now = true;
 
   selected_track       = -1;
@@ -941,7 +947,7 @@ tab_input::on_track_selected(wxCommandEvent &evt) {
 }
 
 void
-tab_input::on_track_enabled(wxCommandEvent &evt) {
+tab_input::on_track_enabled(wxCommandEvent &) {
   unsigned int i;
   for (i = 0; i < tracks.size(); i++) {
     if (mdlg->global_page->cb_webm_mode->IsChecked() && clb_tracks->IsChecked(i) && !tracks[i]->is_webm_compatible()) {
@@ -956,7 +962,7 @@ tab_input::on_track_enabled(wxCommandEvent &evt) {
 }
 
 void
-tab_input::on_value_copy_timer(wxTimerEvent &evt) {
+tab_input::on_value_copy_timer(wxTimerEvent &) {
   if (dont_copy_values_now || (selected_track == -1))
     return;
 
@@ -967,7 +973,7 @@ tab_input::on_value_copy_timer(wxTimerEvent &evt) {
 }
 
 void
-tab_input::on_file_new(wxCommandEvent &evt) {
+tab_input::on_file_new(wxCommandEvent &) {
   b_append_file->Enable(false);
   b_remove_file->Enable(false);
   b_track_up->Enable(false);
@@ -990,7 +996,7 @@ tab_input::save(wxConfigBase *cfg) {
     cfg->Write(wxT("appending"), f->appending);
 
     std::vector<wxString> other_file_names;
-    foreach(const wxFileName other_file_name, f->other_files)
+    for (auto other_file_name : f->other_files)
       other_file_names.push_back(other_file_name.GetFullPath());
     cfg->Write(wxT("other_files"), join(wxT(":::"), other_file_names));
 
@@ -1064,7 +1070,7 @@ tab_input::save(wxConfigBase *cfg) {
 
 void
 tab_input::load(wxConfigBase *cfg,
-                int version) {
+                int) {
   dont_copy_values_now = true;
 
   clb_tracks->Clear();
@@ -1114,7 +1120,7 @@ tab_input::load(wxConfigBase *cfg,
 
     cfg->Read(wxT("other_files"), &s, wxT(""));
     std::vector<wxString> other_file_names = split(s, wxU(":::"));
-    foreach(const wxString &other_file_name, other_file_names)
+    for (auto &other_file_name : other_file_names)
       fi->other_files.push_back(wxFileName(other_file_name));
 
     long tidx;
