@@ -20,14 +20,13 @@
 
 class passthrough_packetizer_c: public generic_packetizer_c {
 public:
-  passthrough_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti)
-    throw (error_c);
+  passthrough_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti);
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "passthrough";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("passthrough") : "passthrough";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
