@@ -103,7 +103,7 @@ vc1_video_packetizer_c::add_timecodes_to_parser(packet_cptr &packet) {
   if (-1 != packet->timecode)
     m_parser.add_timecode(packet->timecode, 0);
 
-  foreach(packet_extension_cptr &extension, packet->extensions) {
+  for (auto &extension : packet->extensions) {
     if (extension->get_type() != packet_extension_c::MULTIPLE_TIMECODES)
       continue;
 
@@ -166,7 +166,7 @@ vc1_video_packetizer_c::flush_frames() {
 
 connection_result_e
 vc1_video_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                       std::string &error_message) {
+                                       std::string &) {
   vc1_video_packetizer_c *vsrc = dynamic_cast<vc1_video_packetizer_c *>(src);
   if (vsrc == NULL)
     return CAN_CONNECT_NO_FORMAT;
