@@ -27,13 +27,13 @@ private:
   bool m_has_correction;
 
 public:
-  wavpack_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, wavpack_meta_t &meta) throw (error_c);
+  wavpack_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, wavpack_meta_t &meta);
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "WAVPACK4";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("WAVPACK4") : "WAVPACK4";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
